@@ -11,16 +11,17 @@ change log:
     2021/06/29  create file.
     2021/08/17  add get_property and to_df function to file, by wuyiran.
 """
-from typing import Optional
+from typing import Optional, Union
 
 import numpy as np
 import pandas as pd
 
 
 class Cell(object):
-    def __init__(self, cell_name: Optional[np.ndarray] = None, cell_border: Optional[np.ndarray] = None):
+    def __init__(self, cell_name: Optional[np.ndarray] = None, cell_border: Optional[np.ndarray] = None, batch: Optional[Union[np.ndarray, list, int, str]] = None):
         self._cell_name = cell_name
         self._cell_border = cell_border
+        self._batch = self._set_batch(batch) if batch is not None else None
         self.total_counts = None
         self.pct_counts_mt = None
         self.n_genes_by_counts = None
@@ -55,6 +56,28 @@ class Cell(object):
         if not isinstance(cell_border, np.ndarray):
             raise TypeError('cell border must be a np.ndarray object.')
         self._cell_border = cell_border
+    
+    @property
+    def batch(self):
+        return self._batch
+    
+    @batch.setter
+    def batch(self, batch: Union[np.ndarray, list, int]):
+        self._batch = self._set_batch(batch)
+
+    def _set_batch(self, batch: Union[np.ndarray, list, int]):
+        if batch is None:
+            return None
+            
+        if not isinstance(batch, np.ndarray) and not isinstance(batch, list) and not isinstance(batch, int) and not isinstance(batch, str):
+            raise TypeError('batch must be np.ndarray or list or int or str')
+        
+        if isinstance(batch, int):
+            batch = str(batch)
+        if isinstance(batch, str):
+            return np.repeat(batch, len(self.cell_name))
+        else:
+            return (np.array(batch) if isinstance(batch, list) else batch).astype('U')
 
     def sub_set(self, index):
         """
@@ -73,6 +96,8 @@ class Cell(object):
             self.pct_counts_mt = self.pct_counts_mt[index]
         if self.n_genes_by_counts is not None:
             self.n_genes_by_counts = self.n_genes_by_counts[index]
+        if self.batch is not None:
+            self.batch = self.batch[index]
         return self
 
     def get_property(self, name):
@@ -100,5 +125,7 @@ class Cell(object):
             'pct_counts_mt': self.pct_counts_mt,
             'n_genes_by_counts': self.n_genes_by_counts
         }
+        if self._batch is not None:
+            attributes['batch'] = self._batch
         df = pd.DataFrame(attributes, index=self.cell_name)
         return df
