@@ -3,5 +3,5 @@
 
 from .pyramid import merge_pyramid, create_pyramid
 from .segmentation.segment import cell_seg
-from .tissue_cut.tissue_seg import tissue_seg
+from . import tissue_cut
 from .segmentation_deepcell.segment import cell_seg_deepcell
