@@ -25,6 +25,7 @@ from stereo.io import h5ad
 from scipy.sparse import csr_matrix
 from stereo.core.cell import Cell
 from stereo.core.gene import Gene
+from stereo.utils.read_write_utils import ReadWriteUtils
 import numpy as np
 from anndata import AnnData
 from shapely.geometry import Point, MultiPoint
@@ -32,6 +33,7 @@ from typing import Optional
 from copy import deepcopy
 
 
+@ReadWriteUtils.check_file_exists
 def read_gem(file_path, sep='\t', bin_type="bins", bin_size=100, is_sparse=True):
     """
     read the stereo-seq file, and generate the object of StereoExpData.
@@ -133,7 +135,7 @@ def to_interval(interval_string):
     interval = pd.Interval(float(left), float(right))
     return interval
 
-
+@ReadWriteUtils.check_file_exists
 def read_stereo_h5ad(file_path, use_raw=True, use_result=True, ):
     """
     read the h5ad file, and generate the object of StereoExpData.
@@ -213,7 +215,7 @@ def read_stereo_h5ad(file_path, use_raw=True, use_result=True, ):
                             data.tl.result[res_key][cluster] = h5ad.read_group(f[cluster_key])
     return data
 
-
+@ReadWriteUtils.check_file_exists
 def read_ann_h5ad(file_path, spatial_key: Optional[str] = None):
     """
     read the h5ad file in Anndata format, and generate the object of StereoExpData.
@@ -497,7 +499,7 @@ def stereo_to_anndata(data: StereoExpData, flavor='scanpy', sample_id="sample",
 #
 #     adata.obs_names = pd.read_csv(barcodesfile, header=None)[0].values
 #     return adata
-
+@ReadWriteUtils.check_file_exists
 def read_gef(file_path: str, bin_type="bins", bin_size=100, is_sparse=True, gene_list: list = None,
              region: list = None):
     """
@@ -540,8 +542,6 @@ def read_gef(file_path: str, bin_type="bins", bin_size=100, is_sparse=True, gene
             data.genes = Gene(gene_name=gene_names)
 
             data.exp_matrix = exp_matrix if is_sparse else exp_matrix.toarray()
-            data.is_all_data = False
-
         else:
             from gefpy.cell_exp_reader import CellExpReader
             cell_bin_gef = CellExpReader(file_path)
@@ -554,7 +554,7 @@ def read_gef(file_path: str, bin_type="bins", bin_size=100, is_sparse=True, gene
     else:
         from gefpy.bgef_reader_cy import BgefR
         gef = BgefR(file_path, bin_size, 4)
-        
+
         data = StereoExpData(file_path=file_path, bin_type=bin_type, bin_size=bin_size)
         data.offset_x, data.offset_y = gef.get_offset()
         gef_attr = gef.get_exp_attr()
@@ -584,7 +584,6 @@ def read_gef(file_path: str, bin_type="bins", bin_size=100, is_sparse=True, gene
             data.genes = Gene(gene_name=gene_names)
 
             data.exp_matrix = exp_matrix if is_sparse else exp_matrix.toarray()
-            data.is_all_data = False
         else:
             gene_num = gef.get_gene_num()
             uniq_cells, rows, count = gef.get_exp_data()
@@ -601,7 +600,7 @@ def read_gef(file_path: str, bin_type="bins", bin_size=100, is_sparse=True, gene
 
     return data
 
-
+@ReadWriteUtils.check_file_exists
 def read_gef_info(file_path: str):
     """
     read the infomation of gef(.h5) file.
