@@ -1,5 +1,7 @@
 import time
 import uuid
+from functools import wraps
+from stereo.log_manager import logger
 
 class TimeConsume:
     def __init__(self):
@@ -43,3 +45,21 @@ class TimeConsume:
         self.time_accumulated = 0
         self.accumulate = False
         return time_accumulated
+    
+    
+def log_consumed_time(outer_func=None, unit='s'):
+    def log(func):
+        @wraps(func)
+        def wrapped(*args, **kwargs):
+            tc = TimeConsume()
+            logger.info('start to run {}...'.format(func.__name__))
+            tk = tc.start()
+            res = func(*args, **kwargs)
+            logger.info('{} end, consume time {:.4f}{}.'.format(func.__name__, tc.get_time_consumed(key=tk, restart=False, unit=unit), unit))
+            return res
+        return wrapped
+    if outer_func is not None:
+        return log(outer_func)
+    else:
+        return log
+
